@@ -17,10 +17,10 @@ struct exportmode {
 	struct strlist hooks;
 };
 
-retvalue exportmode_init(/*@out@*/struct exportmode *mode, bool uncompressed, /*@null@*/const char *release, const char *indexfile);
+retvalue exportmode_init(/*@out@*/struct exportmode *, bool /*uncompressed*/, /*@null@*/const char * /*release*/, const char * /*indexfile*/);
 struct configiterator;
-retvalue exportmode_set(struct exportmode *mode, struct configiterator *iter);
-void exportmode_done(struct exportmode *mode);
+retvalue exportmode_set(struct exportmode *, struct configiterator *);
+void exportmode_done(struct exportmode *);
 
-retvalue export_target(const char *relativedir, struct target *, struct database *, const struct exportmode *, struct release *, bool onlyifmissing, bool snapshot);
+retvalue export_target(const char * /*relativedir*/, struct target *, const struct exportmode *, struct release *, bool /*onlyifmissing*/, bool /*snapshot*/);
 #endif
