@@ -328,7 +328,7 @@ CFSETPROC(incoming, allow) {
 
 CFSETPROC(incoming, permit) {
 	CFSETPROCVARS(incoming, i, d);
-	static const struct constant const permitconstants[] = {
+	static const struct constant permitconstants[] = {
 		{ "unused_files",	pmf_unused_files},
 		{ "older_version",	pmf_oldpackagenewer},
 		{ "unlisted_binaries",	pmf_unlistedbinaries},
@@ -358,7 +358,7 @@ CFSETPROC(incoming, permit) {
 
 CFSETPROC(incoming, cleanup) {
 	CFSETPROCVARS(incoming, i, d);
-	static const struct constant const cleanupconstants[] = {
+	static const struct constant cleanupconstants[] = {
 		{ "unused_files", cuf_unused_files},
 		{ "unused_buildinfo_files", cuf_unused_buildinfo_files},
 		{ "on_deny", cuf_on_deny},
@@ -388,7 +388,7 @@ CFSETPROC(incoming, cleanup) {
 
 CFSETPROC(incoming, options) {
 	CFSETPROCVARS(incoming, i, d);
-	static const struct constant const optionsconstants[] = {
+	static const struct constant optionsconstants[] = {
 		{ "limit_arch_all", iof_limit_arch_all},
 		{ "multiple_distributions", iof_multiple_distributions},
 		{ NULL, -1}
@@ -775,10 +775,13 @@ static retvalue candidate_parse(struct incoming *i, struct candidate *c) {
 		r = properversion(c->sourceversion);
 		E("Malforce Source Version number!");
 	}
-	r = chunk_getwordlist(c->control, "Binary", &c->binaries);
-	E("Missing 'Binary' field!");
 	r = chunk_getwordlist(c->control, "Architecture", &c->architectures);
 	E("Missing 'Architecture' field!");
+	r = chunk_getwordlist(c->control, "Binary", &c->binaries);
+	if (r == RET_NOTHING)
+		strlist_init(&c->binaries);
+	else if (RET_WAS_ERROR(r))
+		return r;
 	r = chunk_getvalue(c->control, "Version", &c->changesversion);
 	E("Missing 'Version' field!");
 	r = properversion(c->changesversion);
@@ -998,7 +1001,7 @@ static retvalue candidate_read_deb(struct incoming *i, struct candidate *c, stru
 	char *base;
 	const char *packagenametocheck;
 
-	r = binaries_readdeb(&file->deb, file->tempfilename, true);
+	r = binaries_readdeb(&file->deb, file->tempfilename);
 	if (RET_WAS_ERROR(r))
 		return r;
 	if (strcmp(file->name, file->deb.name) != 0) {
@@ -1443,6 +1446,35 @@ static retvalue prepare_dsc(const struct incoming *i, const struct candidate *c,
 		r = properfilenames(&file->dsc.files.names);
 	if (RET_WAS_ERROR(r))
 		return r;
+
+	/* check if signatures match files signed: */
+	for (j = 0 ; j < file->dsc.files.names.count ; j++) {
+		int jj;
+		const char *afn = file->dsc.files.names.values[j];
+		size_t al = strlen(afn);
+		bool found = false;
+
+		if (al <= 4 || memcmp(afn + al - 4, ".asc", 4) != 0)
+			continue;
+
+		for (jj = 0 ; jj < file->dsc.files.names.count ; jj++) {
+			const char *fn = file->dsc.files.names.values[jj];
+			size_t l = strlen(fn);
+
+			if (l + 4 != al)
+				continue;
+			if (memcmp(afn, fn, l) != 0)
+				continue;
+			found = true;
+			break;
+		}
+		if (!found) {
+			fprintf(stderr,
+"Signature file without file to be signed: '%s'!\n", afn);
+			return RET_ERROR;
+		}
+	}
+
 	oinfo = override_search(into->overrides.dsc, file->dsc.name);
 
 	r = getsectionprioritycomponent(i, c, into, file,
@@ -1759,7 +1791,7 @@ static retvalue add_dsc(struct distribution *into, struct trackingdata *tracking
 					&p->filekeys,
 					false, trackingdata,
 					architecture_source,
-					NULL, NULL, NULL);
+					NULL, NULL);
 		r2 = target_closepackagesdb(t);
 		RET_ENDUPDATE(r, r2);
 	}
@@ -2239,7 +2271,7 @@ static retvalue candidate_really_add(struct incoming *i, struct candidate *c) {
 		} else if (d->byhandhookstocall == NULL)
 			continue;
 		logger_logchanges(into->logger, into->codename,
-				c->source, c->changesversion, c->control,
+				c->source, c->changesversion,
 				changesfile(c)->tempfilename, changesfilekey);
 	}
 	return RET_OK;
